summaryrefslogtreecommitdiffstats
path: root/lib/kformula/errorelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/errorelement.h')
-rw-r--r--lib/kformula/errorelement.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kformula/errorelement.h b/lib/kformula/errorelement.h
index bc23b5e2..c7d69fed 100644
--- a/lib/kformula/errorelement.h
+++ b/lib/kformula/errorelement.h
@@ -31,15 +31,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& parentOrigin );
private:
virtual TQString getElementName() const { return "merror"; }
@@ -31,15 +31,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,